@@ -24,7 +24,7 @@ pub struct Account {
 
 impl Account {
     pub fn new(leverage: f64, starting_balance: f64, futures_type: FuturesTypes) -> Self {
-        let position = Position::new(leverage);
+        let position = Position::new_init(leverage);
         let margin = Margin::new_init(starting_balance);
         let acc_tracker = AccTracker::new(starting_balance);
         Self {
@@ -183,8 +183,10 @@ impl Account {
             }
         }
         // assign order margin
-        let om = credit - debit;
+        let om = credit; // - debit;
         debug_assert!(om >= 0.0);
+        // assigning order margin and closing out position are two different things
+
         self.order_margins.insert(order.id(), om);
         let new_om = self.margin.order_margin() + om;
         self.margin.set_order_margin(new_om);
@@ -247,7 +249,7 @@ impl Account {
 
     /// Changes the position by a given delta while changing margin accordingly
     pub(crate) fn change_position(&mut self, side: Side, size: f64, exec_price: f64) {
-        trace!(
+        debug!(
             "account: change_position(side: {:?}, size: {}, exec_price: {})",
             side,
             size,
@@ -315,49 +317,24 @@ impl Account {
     }
 
     #[inline(always)]
-    pub(crate) fn open_limit_buy_size(&self) -> f64 { self.open_limit_buy_size }
+    pub(crate) fn open_limit_buy_size(&self) -> f64 {
+        self.open_limit_buy_size
+    }
 
     #[inline(always)]
-    pub(crate) fn open_limit_sell_size(&self) -> f64 { self.open_limit_sell_size }
+    pub(crate) fn open_limit_sell_size(&self) -> f64 {
+        self.open_limit_sell_size
+    }
 
     #[inline(always)]
-    pub(crate) fn min_limit_buy_price(&self) -> f64 { self.min_limit_buy_price }
+    pub(crate) fn min_limit_buy_price(&self) -> f64 {
+        self.min_limit_buy_price
+    }
 
     #[inline(always)]
-    pub(crate) fn max_limit_sell_price(&self) -> f64 { self.max_limit_sell_price }
-
-    // /// Calculate the order margin to assign for a given order
-    // #[must_use]
-    // fn order_margin(&self, o: &Order) -> f64 {
-    //     match o.side() {
-    //         Side::Buy => {}
-    //         Side::Sell => {}
-    //     }
-    //
-    //     // let ps: f64 = self.position.size();
-    //     // let open_sizes: [f64; 2] = [self.open_limit_buy_size, self.open_limit_sell_size];
-    //     // let mut max_idx: usize = 0;
-    //     // let mut m: f64 = self.open_limit_buy_size;
-    //     //
-    //     // for (i, s) in open_sizes.iter().enumerate() {
-    //     //     if *s > m {
-    //     //         m = *s;
-    //     //         max_idx = i;
-    //     //     }
-    //     // }
-    //     //
-    //     // // direction of dominating open order side
-    //     // let (d, p) = match max_idx {
-    //     //     0 => (1.0, self.min_limit_buy_price),
-    //     //     1 => (-1.0, self.max_limit_sell_price),
-    //     //     _ => panic!("any other value should not be possible"),
-    //     // };
-    //     // if p == 0.0 {
-    //     //     return 0.0;
-    //     // }
-    //     //
-    //     // max(0.0, min(m, m + d * ps)) / p / self.position.leverage()
-    // }
+    pub(crate) fn max_limit_sell_price(&self) -> f64 {
+        self.max_limit_sell_price
+    }
 }
 
 #[cfg(test)]
